@@ -3,6 +3,7 @@ import json
 import logging
 import os
 import sys
+from os.path import expanduser
 
 import openai
 
@@ -75,7 +76,9 @@ def init_logging(debug: bool):
     )
 
 
-key_file = "/tmp/gptw-key.txt"
+CURRENT_FOLDER = os.path.dirname(os.path.abspath(__file__))
+cfg_file = os.path.join(CURRENT_FOLDER, "config.json")
+key_file = os.path.join(expanduser("~"), ".gptw-key.txt")
 
 
 def set_apikey(key):
@@ -88,9 +91,6 @@ def get_apikey():
         openai.api_key = f.readline().strip()
 
 
-cfg_file = os.path.join(os.path.dirname(os.path.abspath(__file__)), "config.json")
-
-
 def get_configs():
     with open(cfg_file) as f:
         return json.load(f)["cmds"]
@@ -113,6 +113,7 @@ def ask_gpt_with(pre, text):
 def main():
     args = args_init()
     init_logging(args.debug)
+    logging.debug(f"src folder: {CURRENT_FOLDER}")
 
     if args.key:
         logging.debug("key mode")
